@@ -1,5 +1,5 @@
 from flask import send_from_directory
-from IQRServer import *
+from .IQRServer import *
 from abc import abstractmethod
 import os.path
 
