@@ -1,4 +1,4 @@
-from IQRServer import QRContext
+from .IQRServer import QRContext
 
 
 def role_manager(default_role='guest'):
